nlohmann_json: JSON for modern C++
==================================

Description
-----------

JSON library


License
-------

MIT


Upstream Contact
----------------

https://github.com/nlohmann/json
